@@ -25,13 +25,15 @@ def title(axe,
           extra="",
           cms_energy=True,
           pdf_info=True,
+          id=False,
           **kwargs):
     """Sets the title on axis `axe`."""
     axe.set_title("$pp\\to" + get_name(i.particle1) + get_name(i.particle2) +
                   "$" + (" at $\\sqrt{S} = " + str(i.energy / 1000) +
                          "$ TeV" if cms_energy else "") + " for " +
                   (i.slha.split(".")[0] if scenario == "" else scenario) +
-                  (" with " + i.pdf_nlo if pdf_info else "") + " " + extra)
+                  (" with " + i.pdf_nlo if pdf_info else "") + " " + extra +
+                  ((" [" + i.id + "]") if id else ""))
 
 
 def energy_plot(dict_list,
@@ -134,7 +136,7 @@ def plot(dict_list,
         >>> dl = hepi.load(urllib.request.urlopen(
         ... "https://raw.githubusercontent.com/fuenfundachtzig/xsec/master/json/pp13_hino_NLO%2BNLL.json"
         ... ))
-        >>> hepi.plot(dl,"N1","NLO_PLUS_NLL",xaxis="$m_{\\\\tilde{\\\\chi}_1^0}$")
+        >>> hepi.plot(dl,"N1","NLO_PLUS_NLL",xaxis="$m_{\\\\tilde{\\\\chi}_1^0}$ [GeV]")
     """
     if isinstance(y, Iterable) and not isinstance(y, str):
         for yi in y:
@@ -147,8 +149,8 @@ def plot(dict_list,
     if label == "":
         label = None
 
-    vx = dict_list[x][mask]
-    vy = dict_list[y][mask]
+    vx = dict_list[x].to_numpy()[mask]
+    vy = dict_list[y].to_numpy()[mask]
 
     if K:
         yaxis = "$K$"
@@ -221,83 +223,46 @@ def vplot(x,
         vx = x
         vy = y
 
-    xnew = np.linspace(
-        vx[0],
-        vx[-1],
-        300,
-    )
-    if interpolate:
-        #print(vx,vy)
-        spl = make_interp_spline(vx, splot.unv(vy), k=3)  # type: BSpline
-        power_smooth = spl(xnew)
-    if fill:
-        spl_up = make_interp_spline(vx, splot.unv(vy) + splot.usd(vy),
-                                    k=3)  # type: BSpline
-        power_up_smooth = spl_up(xnew)
-        spl_down = make_interp_spline(vx, splot.unv(vy) - splot.usd(vy),
-                                      k=3)  # type: BSpline
-        power_down_smooth = spl_down(xnew)
+    
     if data_color is None:
         if 'axes' in kwargs and kwargs['axes'] is not None:
             bl, = kwargs['axes'].plot([], [])
         else:
             bl, = plt.gca().plot([], [])
         color = bl.get_color()
-    if plot_data:
+    iii = splot.data(vx,
+                            vy * yscale,
+                            label=label,
+                            xaxis=xaxis,
+                            yaxis=yaxis,
+                            logy=logy,
+                            data_color=color,
+                            also_data=plot_data,
+                            interpolate=interpolate,
+                            fmt=data_fmt,
+                            sigmas=0 if not fill else 1,
+                            **kwargs)
+    if iii is not None:
+        #ii = iii[0]
+        ix = iii[1]
+        iy = iii[2]
+    if print_area:
+        print('computed AUC using sklearn.metrics.auc: {}'.format(auc(ix, iy)))
+    if ((np.any(np.less(vy, 0)) or (interpolate and np.any(np.less(iy, 0))))
+            and logy):
         splot.data(vx,
-                   vy * yscale,
-                   label=label,
+                   -vy * yscale,
+                   label="-" + label,
                    xaxis=xaxis,
                    yaxis=yaxis,
                    logy=logy,
                    data_color=color,
+                   also_data=plot_data,
+                   interpolate=interpolate,
+                   interpolate_fmt=(0, (3, 1, 3, 1, 1, 1)),
                    fmt=data_fmt,
+                   sigmas=0 if not fill else 1,
                    **kwargs)
-    if interpolate:
-        kargs = {}
-        if not plot_data:
-            kargs = {'xaxis': xaxis, 'yaxis': yaxis, 'label': label}
-        if print_area:
-            print('computed AUC using sklearn.metrics.auc: {}'.format(
-                auc(xnew, power_smooth * yscale)))
-        splot.data(xnew,
-                   power_smooth * yscale,
-                   logy=logy,
-                   fmt=fmt,
-                   init=False,
-                   data_color=color,
-                   **kargs,
-                   **kwargs)
-    if fill:
-        plt.fill_between(xnew,
-                         power_up_smooth * yscale,
-                         power_down_smooth * yscale,
-                         alpha=0.3,
-                         color=color)
-    if ((np.any(np.less(vy, 0)) or
-         (interpolate and np.any(np.less(power_smooth, 0)))) and logy):
-        if plot_data:
-            splot.data(vx,
-                       -vy * yscale,
-                       label="-" + label,
-                       xaxis=xaxis,
-                       yaxis=yaxis,
-                       logy=logy,
-                       data_color=color,
-                       fmt=data_fmt,
-                       **kwargs)
-        if interpolate:
-            if not plot_data:
-                kargs = {'xaxis': xaxis, 'yaxis': yaxis, 'label': "-" + label}
-            splot.data(xnew,
-                       -power_smooth * yscale,
-                       logy=logy,
-                       fmt=None,
-                       linestyle=(0, (3, 1, 3, 1, 1, 1)),
-                       init=False,
-                       data_color=color,
-                       **kargs,
-                       **kwargs)
 
 
 def mass_mapplot(dict_list,
@@ -329,10 +294,11 @@ def mapplot(dict_list, x, y, z, xaxis=None, yaxis=None, zaxis=None, **kwargs):
 
         >>> import urllib.request
         >>> import hepi 
+
         >>> dl = hepi.load(urllib.request.urlopen(
-        ... "https://raw.githubusercontent.com/fuenfundachtzig/xsec/master/json/pp13_hinosplit_N2N1_NLO%2BNLL.json"
+        ... "https://raw.githubusercontent.com/APN-Pucky/xsec/master/json/pp13_SGmodel_GGxsec_NLO%2BNLL.json"
         ... ),dimensions=2)
-        >>> hepi.mapplot(dl,"N1","N2","NLO_PLUS_NLL",xaxis="$m_{\\\\tilde{\\\\chi}_1^0}$",yaxis="$m_{\\\\tilde{\\\\chi}_2^0}$" , zaxis="$\\\\sigma_{\\\\mathrm{NLO+NLL}}$")
+        >>> hepi.mapplot(dl,"gl","sq","NLO_PLUS_NLL",xaxis="$m_{\\\\tilde{g}}$ [GeV]",yaxis="$m_{\\\\tilde{q}}$ [GeV]" , zaxis="$\\\\sigma_{\\\\mathrm{NLO+NLL}}$ [pb]")
     """
     if xaxis is None:
         xaxis = x
@@ -343,85 +309,60 @@ def mapplot(dict_list, x, y, z, xaxis=None, yaxis=None, zaxis=None, **kwargs):
     vx = dict_list[x]
     vy = dict_list[y]
     vz = dict_list[z]
-    map_vplot(vx, vy, vz, xaxis=xaxis, yaxis=yaxis, zaxis=zaxis, **kwargs)
+    splot.plot2d(vx,
+                 vy,
+                 vz,
+                 style="image",
+                 xaxis=xaxis,
+                 yaxis=yaxis,
+                 zaxis=zaxis,
+                 **kwargs)
 
+map_vplot =  lambda *a,**da : splot.plot2d(*a,style="image",**da)
+scatter_vplot =  lambda *a,**da : splot.plot2d(*a,style="scatter",**da)
 
-def map_vplot(vx,
-              vy,
-              vz,
-              xaxis=None,
-              yaxis=None,
-              zaxis=None,
-              logz=True,
-              sort=True,
-              fill_missing=True,
-              zscale=1.):
-    if fill_missing:
-        for x in vx:
-            for y in vy:
-                ex = False
-                for i in range(len(vx)):
-                    if vx[i] == x and vy[i] == y:
-                        ex = True
-                if not ex:
-                    vx = np.append(vx, x)
-                    vy = np.append(vy, y)
-                    vz = np.append(vz, 0)
-    if sort:
-        p1 = vx.argsort(kind='stable')
-        tvx = vx[p1]
-        tvy = vy[p1]
-        tvz = vz[p1]
-        p2 = tvy.argsort(kind='stable')
-        vx = tvx[p2]
-        vy = tvy[p2]
-        vz = tvz[p2]
-    s = 1
-    while vy[s] == vy[s - 1]:
-        s = s + 1
-    if s == 1:
-        #print("flipped x y ")
-        while vx[s] == vx[s - 1]:
-            s = s + 1
-        if s == 1:
-            print("error too small map")
-            return
-        #x, y = y, x
-        xaxis, yaxis = yaxis, xaxis
-        vx, vy = vy, vx
+def scatterplot(dict_list,
+                x,
+                y,
+                z,
+                xaxis=None,
+                yaxis=None,
+                zaxis=None,
+                **kwargs):
+    """
+    Scatter map 2d.
+    Central color is the central value, while the inner and outer ring are lower and upper bounds of the uncertainty interval.
 
-    grid = splot.unv(vz).reshape((int(np.rint(np.size(vx) / s)), s)) * zscale
+    Examples
 
-    fig, ax = plt.subplots(nrows=1, ncols=1, constrained_layout=True)
-    im = None
-    if (logz):
-        im = NonUniformImage(
-            ax,
-            origin="lower",
-            cmap='viridis',
-            interpolation='nearest',
-            extent=(vx.min(), vx.max(), vy.min(), vy.max()),
-            norm=colors.LogNorm(),
-        )
-    else:
-        im = NonUniformImage(
-            ax,
-            origin="lower",
-            cmap='viridis',
-            interpolation='nearest',
-            extent=(vx.min(), vx.max(), vy.min(), vy.max()),
-        )
+    .. plot::
+        :include-source:
 
-    im.set_data(np.unique(vx), np.unique(vy), grid)
-    ax.images.append(im)
-    ax.set_xlim(vx.min(), vx.max())
-    ax.set_ylim(vy.min(), vy.max())
+        >>> import urllib.request
+        >>> import hepi 
+        >>> dl = hepi.load(urllib.request.urlopen(
+        ... "https://raw.githubusercontent.com/APN-Pucky/xsec/master/json/pp13_hinosplit_N2N1_NLO%2BNLL.json"
+        ... ),dimensions=2)
+        >>> hepi.scatterplot(dl,"N1","N2","NLO_PLUS_NLL",xaxis="$m_{\\\\tilde{\\\\chi}_1^0}$ [GeV]",yaxis="$m_{\\\\tilde{\\\\chi}_2^0}$ [GeV]" , zaxis="$\\\\sigma_{\\\\mathrm{NLO+NLL}}$ [pb]")
 
-    cb = plt.colorbar(im)
-    cb.set_label(zaxis)
-    plt.xlabel(xaxis)
-    plt.ylabel(yaxis)
-    plt.show()
+    """
+    if xaxis is None:
+        xaxis = x
+    if yaxis is None:
+        yaxis = y
+    if zaxis is None:
+        zaxis = replace_macros(z)
+    vx = dict_list[x]
+    vy = dict_list[y]
+    vz = dict_list[z]
+    splot.plot2d(vx,
+                 vy,
+                 vz,
+                 style="scatter",
+                 xaxis=xaxis,
+                 yaxis=yaxis,
+                 zaxis=zaxis,
+                 **kwargs)
 
 
 fig = None
@@ -671,4 +612,4 @@ def init_double_plot(figsize=(6, 8),
                             gridspec_kw=gridspec_kw)
     # Remove horizontal space between axes
     fig.subplots_adjust(hspace=0)
-    return fig, axs
\ No newline at end of file
+    return fig, axs
